"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const cli_progress_1 = require("cli-progress");
const index_1 = require("../../src/index");
const testUtils_1 = require("../testUtils");
const XRPMccConnection = {
    url: process.env.XRP_URL || "",
    username: process.env.XRP_USERNAME || "",
    password: process.env.XRP_PASSWORD || "",
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
};
describe(`XRP transactions in full block vs transactions from getTransaction (${(0, testUtils_1.getTestFile)(__filename)})`, () => {
    const blockNumbersToCheck = [75798761, 78915959, (0, testUtils_1.getRandomNumber)(70000000, 79362506)];
    for (const blockNumber of blockNumbersToCheck) {
        describe(`Testing transactions in block ${blockNumber} (transitions from full block vs )`, () => {
            let client;
            let block;
            let fullBlock;
            before(async () => {
                client = new index_1.MCC.XRP(XRPMccConnection);
                block = await client.getBlock(blockNumber);
                fullBlock = await client.getFullBlock(blockNumber);
            });
            it("Block and Full block transaction count should be equal", () => {
                (0, chai_1.expect)(block.transactionCount).to.eq(fullBlock.transactionCount);
            });
            it("Block and Full block transaction ids should be equal", () => {
                (0, chai_1.expect)(block.transactionIds.sort()).to.deep.eq(fullBlock.transactionIds.sort());
            });
            it("Iterating over transactions", async () => {
                const transactions = fullBlock.transactions;
                const b1 = new cli_progress_1.SingleBar({
                    format: `|| {bar} || Checking block || {percentage}% || {value}/{total} Transactions`,
                    barCompleteChar: "\u2588",
                    barIncompleteChar: "\u2591",
                    hideCursor: true,
                });
                b1.start(transactions.length, 0);
                (0, chai_1.expect)(transactions.length).to.be.greaterThan(0);
                for (const transaction of transactions) {
                    b1.increment();
                    // if (i != 83) {
                    //    continue;
                    // }
                    const transObject = await (0, index_1.retry)("get test transactions", () => client.getTransaction(transaction.txid));
                    // console.log(transObject.txid);
                    for (const getter of testUtils_1.GETTERS_BASIC) {
                        (0, testUtils_1.throwOrReturnSameGetter)(transaction, transObject, getter);
                    }
                    for (const getter of testUtils_1.GETTERS_LISTS) {
                        (0, testUtils_1.throwOrReturnSameGetterList)(transaction, transObject, getter);
                    }
                    for (const getter of testUtils_1.GETTERS_AMOUNTS) {
                        (0, testUtils_1.throwOrReturnSameGetterAmounts)(transaction, transObject, getter);
                    }
                    for (const getter of testUtils_1.GETTERS_BN) {
                        (0, testUtils_1.throwOrReturnSameGetterBN)(transaction, transObject, getter);
                    }
                }
                b1.stop();
            });
        });
    }
});
//# sourceMappingURL=transactionsVsTransactionsInBlock.test.js.map